pub struct ChiseledCinnabar;Trait Implementations
Sourceimpl BlockTrait for ChiseledCinnabar
impl BlockTrait for ChiseledCinnabar
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for ChiseledCinnabar
impl Clone for ChiseledCinnabar
Sourcefn clone(&self) -> ChiseledCinnabar
fn clone(&self) -> ChiseledCinnabar
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ChiseledCinnabar
Sourceimpl Debug for ChiseledCinnabar
impl Debug for ChiseledCinnabar
Sourceimpl Default for ChiseledCinnabar
impl Default for ChiseledCinnabar
Sourceimpl From<ChiseledCinnabar> for BlockState
impl From<ChiseledCinnabar> for BlockState
Sourcefn from(b: ChiseledCinnabar) -> Self
fn from(b: ChiseledCinnabar) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChiseledCinnabar
impl PartialEq for ChiseledCinnabar
Sourcefn eq(&self, other: &ChiseledCinnabar) -> bool
fn eq(&self, other: &ChiseledCinnabar) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChiseledCinnabar