pub struct ChiseledSulfur;Trait Implementations
Sourceimpl BlockTrait for ChiseledSulfur
impl BlockTrait for ChiseledSulfur
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for ChiseledSulfur
impl Clone for ChiseledSulfur
Sourcefn clone(&self) -> ChiseledSulfur
fn clone(&self) -> ChiseledSulfur
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ChiseledSulfur
Sourceimpl Debug for ChiseledSulfur
impl Debug for ChiseledSulfur
Sourceimpl Default for ChiseledSulfur
impl Default for ChiseledSulfur
Sourceimpl From<ChiseledSulfur> for BlockState
impl From<ChiseledSulfur> for BlockState
Sourcefn from(b: ChiseledSulfur) -> Self
fn from(b: ChiseledSulfur) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChiseledSulfur
impl PartialEq for ChiseledSulfur
Sourcefn eq(&self, other: &ChiseledSulfur) -> bool
fn eq(&self, other: &ChiseledSulfur) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChiseledSulfur