pub struct CinnabarBrickSlab {
pub kind: SlabKind,
pub waterlogged: bool,
}Fields
kind: SlabKindwaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for CinnabarBrickSlab
impl BlockTrait for CinnabarBrickSlab
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for CinnabarBrickSlab
impl Clone for CinnabarBrickSlab
Sourcefn clone(&self) -> CinnabarBrickSlab
fn clone(&self) -> CinnabarBrickSlab
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CinnabarBrickSlab
Sourceimpl Debug for CinnabarBrickSlab
impl Debug for CinnabarBrickSlab
Sourceimpl Default for CinnabarBrickSlab
impl Default for CinnabarBrickSlab
Sourceimpl From<CinnabarBrickSlab> for BlockState
impl From<CinnabarBrickSlab> for BlockState
Sourcefn from(b: CinnabarBrickSlab) -> Self
fn from(b: CinnabarBrickSlab) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CinnabarBrickSlab
impl PartialEq for CinnabarBrickSlab
Sourcefn eq(&self, other: &CinnabarBrickSlab) -> bool
fn eq(&self, other: &CinnabarBrickSlab) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CinnabarBrickSlab