pub struct CinnabarBrickStairs {
pub facing: FacingCardinal,
pub half: TopBottom,
pub shape: StairShape,
pub waterlogged: bool,
}Fields
facing: FacingCardinalhalf: TopBottomshape: StairShapewaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for CinnabarBrickStairs
impl BlockTrait for CinnabarBrickStairs
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for CinnabarBrickStairs
impl Clone for CinnabarBrickStairs
Sourcefn clone(&self) -> CinnabarBrickStairs
fn clone(&self) -> CinnabarBrickStairs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CinnabarBrickStairs
Sourceimpl Debug for CinnabarBrickStairs
impl Debug for CinnabarBrickStairs
Sourceimpl Default for CinnabarBrickStairs
impl Default for CinnabarBrickStairs
Sourceimpl From<CinnabarBrickStairs> for BlockState
impl From<CinnabarBrickStairs> for BlockState
Sourcefn from(b: CinnabarBrickStairs) -> Self
fn from(b: CinnabarBrickStairs) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CinnabarBrickStairs
impl PartialEq for CinnabarBrickStairs
Sourcefn eq(&self, other: &CinnabarBrickStairs) -> bool
fn eq(&self, other: &CinnabarBrickStairs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CinnabarBrickStairs