pub struct CinnabarBrickWall {
pub east: WallEast,
pub north: WallNorth,
pub south: WallSouth,
pub up: bool,
pub waterlogged: bool,
pub west: WallWest,
}Fields
east: WallEastnorth: WallNorthsouth: WallSouthup: boolwaterlogged: boolwest: WallWestTrait Implementations
Sourceimpl BlockTrait for CinnabarBrickWall
impl BlockTrait for CinnabarBrickWall
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for CinnabarBrickWall
impl Clone for CinnabarBrickWall
Sourcefn clone(&self) -> CinnabarBrickWall
fn clone(&self) -> CinnabarBrickWall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CinnabarBrickWall
Sourceimpl Debug for CinnabarBrickWall
impl Debug for CinnabarBrickWall
Sourceimpl Default for CinnabarBrickWall
impl Default for CinnabarBrickWall
Sourceimpl From<CinnabarBrickWall> for BlockState
impl From<CinnabarBrickWall> for BlockState
Sourcefn from(b: CinnabarBrickWall) -> Self
fn from(b: CinnabarBrickWall) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CinnabarBrickWall
impl PartialEq for CinnabarBrickWall
Sourcefn eq(&self, other: &CinnabarBrickWall) -> bool
fn eq(&self, other: &CinnabarBrickWall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CinnabarBrickWall