pub struct CinnabarSlab {
pub kind: SlabKind,
pub waterlogged: bool,
}Fields
kind: SlabKindwaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for CinnabarSlab
impl BlockTrait for CinnabarSlab
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for CinnabarSlab
impl Clone for CinnabarSlab
Sourcefn clone(&self) -> CinnabarSlab
fn clone(&self) -> CinnabarSlab
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CinnabarSlab
Sourceimpl Debug for CinnabarSlab
impl Debug for CinnabarSlab
Sourceimpl Default for CinnabarSlab
impl Default for CinnabarSlab
Sourceimpl From<CinnabarSlab> for BlockState
impl From<CinnabarSlab> for BlockState
Sourcefn from(b: CinnabarSlab) -> Self
fn from(b: CinnabarSlab) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CinnabarSlab
impl PartialEq for CinnabarSlab
Sourcefn eq(&self, other: &CinnabarSlab) -> bool
fn eq(&self, other: &CinnabarSlab) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CinnabarSlab