pub struct CinnabarStairs {
pub facing: FacingCardinal,
pub half: TopBottom,
pub shape: StairShape,
pub waterlogged: bool,
}Fields
facing: FacingCardinalhalf: TopBottomshape: StairShapewaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for CinnabarStairs
impl BlockTrait for CinnabarStairs
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for CinnabarStairs
impl Clone for CinnabarStairs
Sourcefn clone(&self) -> CinnabarStairs
fn clone(&self) -> CinnabarStairs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CinnabarStairs
Sourceimpl Debug for CinnabarStairs
impl Debug for CinnabarStairs
Sourceimpl Default for CinnabarStairs
impl Default for CinnabarStairs
Sourceimpl From<CinnabarStairs> for BlockState
impl From<CinnabarStairs> for BlockState
Sourcefn from(b: CinnabarStairs) -> Self
fn from(b: CinnabarStairs) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CinnabarStairs
impl PartialEq for CinnabarStairs
Sourcefn eq(&self, other: &CinnabarStairs) -> bool
fn eq(&self, other: &CinnabarStairs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CinnabarStairs