pub struct PolishedCinnabar;Trait Implementations
Sourceimpl BlockTrait for PolishedCinnabar
impl BlockTrait for PolishedCinnabar
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for PolishedCinnabar
impl Clone for PolishedCinnabar
Sourcefn clone(&self) -> PolishedCinnabar
fn clone(&self) -> PolishedCinnabar
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PolishedCinnabar
Sourceimpl Debug for PolishedCinnabar
impl Debug for PolishedCinnabar
Sourceimpl Default for PolishedCinnabar
impl Default for PolishedCinnabar
Sourceimpl From<PolishedCinnabar> for BlockState
impl From<PolishedCinnabar> for BlockState
Sourcefn from(b: PolishedCinnabar) -> Self
fn from(b: PolishedCinnabar) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PolishedCinnabar
impl PartialEq for PolishedCinnabar
Sourcefn eq(&self, other: &PolishedCinnabar) -> bool
fn eq(&self, other: &PolishedCinnabar) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PolishedCinnabar