pub struct PolishedCinnabarStairs {
pub facing: FacingCardinal,
pub half: TopBottom,
pub shape: StairShape,
pub waterlogged: bool,
}Fields
facing: FacingCardinalhalf: TopBottomshape: StairShapewaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for PolishedCinnabarStairs
impl BlockTrait for PolishedCinnabarStairs
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for PolishedCinnabarStairs
impl Clone for PolishedCinnabarStairs
Sourcefn clone(&self) -> PolishedCinnabarStairs
fn clone(&self) -> PolishedCinnabarStairs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PolishedCinnabarStairs
Sourceimpl Debug for PolishedCinnabarStairs
impl Debug for PolishedCinnabarStairs
Sourceimpl Default for PolishedCinnabarStairs
impl Default for PolishedCinnabarStairs
Sourceimpl From<PolishedCinnabarStairs> for BlockState
impl From<PolishedCinnabarStairs> for BlockState
Sourcefn from(b: PolishedCinnabarStairs) -> Self
fn from(b: PolishedCinnabarStairs) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PolishedCinnabarStairs
impl PartialEq for PolishedCinnabarStairs
Sourcefn eq(&self, other: &PolishedCinnabarStairs) -> bool
fn eq(&self, other: &PolishedCinnabarStairs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PolishedCinnabarStairs