pub struct PolishedSulfur;Trait Implementations
Sourceimpl BlockTrait for PolishedSulfur
impl BlockTrait for PolishedSulfur
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for PolishedSulfur
impl Clone for PolishedSulfur
Sourcefn clone(&self) -> PolishedSulfur
fn clone(&self) -> PolishedSulfur
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PolishedSulfur
Sourceimpl Debug for PolishedSulfur
impl Debug for PolishedSulfur
Sourceimpl Default for PolishedSulfur
impl Default for PolishedSulfur
Sourceimpl From<PolishedSulfur> for BlockState
impl From<PolishedSulfur> for BlockState
Sourcefn from(b: PolishedSulfur) -> Self
fn from(b: PolishedSulfur) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PolishedSulfur
impl PartialEq for PolishedSulfur
Sourcefn eq(&self, other: &PolishedSulfur) -> bool
fn eq(&self, other: &PolishedSulfur) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PolishedSulfur