pub struct PolishedSulfurStairs {
pub facing: FacingCardinal,
pub half: TopBottom,
pub shape: StairShape,
pub waterlogged: bool,
}Fields
facing: FacingCardinalhalf: TopBottomshape: StairShapewaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for PolishedSulfurStairs
impl BlockTrait for PolishedSulfurStairs
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for PolishedSulfurStairs
impl Clone for PolishedSulfurStairs
Sourcefn clone(&self) -> PolishedSulfurStairs
fn clone(&self) -> PolishedSulfurStairs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PolishedSulfurStairs
Sourceimpl Debug for PolishedSulfurStairs
impl Debug for PolishedSulfurStairs
Sourceimpl Default for PolishedSulfurStairs
impl Default for PolishedSulfurStairs
Sourceimpl From<PolishedSulfurStairs> for BlockState
impl From<PolishedSulfurStairs> for BlockState
Sourcefn from(b: PolishedSulfurStairs) -> Self
fn from(b: PolishedSulfurStairs) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PolishedSulfurStairs
impl PartialEq for PolishedSulfurStairs
Sourcefn eq(&self, other: &PolishedSulfurStairs) -> bool
fn eq(&self, other: &PolishedSulfurStairs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PolishedSulfurStairs