pub struct PotentSulfur {
pub potent_sulfur_state: PotentSulfurState,
}Fields
potent_sulfur_state: PotentSulfurStateTrait Implementations
Sourceimpl BlockTrait for PotentSulfur
impl BlockTrait for PotentSulfur
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for PotentSulfur
impl Clone for PotentSulfur
Sourcefn clone(&self) -> PotentSulfur
fn clone(&self) -> PotentSulfur
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PotentSulfur
Sourceimpl Debug for PotentSulfur
impl Debug for PotentSulfur
Sourceimpl Default for PotentSulfur
impl Default for PotentSulfur
Sourceimpl From<PotentSulfur> for BlockState
impl From<PotentSulfur> for BlockState
Sourcefn from(b: PotentSulfur) -> Self
fn from(b: PotentSulfur) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PotentSulfur
impl PartialEq for PotentSulfur
Sourcefn eq(&self, other: &PotentSulfur) -> bool
fn eq(&self, other: &PotentSulfur) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PotentSulfur