pub struct PottedGoldenDandelion;Trait Implementations
Sourceimpl BlockTrait for PottedGoldenDandelion
impl BlockTrait for PottedGoldenDandelion
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn as_block_kind(&self) -> BlockKind
fn as_block_kind(&self) -> BlockKind
Convert the block struct to a [
BlockKind]. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for PottedGoldenDandelion
impl Clone for PottedGoldenDandelion
Sourcefn clone(&self) -> PottedGoldenDandelion
fn clone(&self) -> PottedGoldenDandelion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PottedGoldenDandelion
impl Debug for PottedGoldenDandelion
Sourceimpl Default for PottedGoldenDandelion
impl Default for PottedGoldenDandelion
Sourceimpl From<PottedGoldenDandelion> for BlockState
impl From<PottedGoldenDandelion> for BlockState
Sourcefn from(b: PottedGoldenDandelion) -> Self
fn from(b: PottedGoldenDandelion) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PottedGoldenDandelion
impl PartialEq for PottedGoldenDandelion
impl Copy for PottedGoldenDandelion
impl StructuralPartialEq for PottedGoldenDandelion