pub struct SulfurBrickWall {
pub east: WallEast,
pub north: WallNorth,
pub south: WallSouth,
pub up: bool,
pub waterlogged: bool,
pub west: WallWest,
}Fields
east: WallEastnorth: WallNorthsouth: WallSouthup: boolwaterlogged: boolwest: WallWestTrait Implementations
Sourceimpl BlockTrait for SulfurBrickWall
impl BlockTrait for SulfurBrickWall
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for SulfurBrickWall
impl Clone for SulfurBrickWall
Sourcefn clone(&self) -> SulfurBrickWall
fn clone(&self) -> SulfurBrickWall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SulfurBrickWall
Sourceimpl Debug for SulfurBrickWall
impl Debug for SulfurBrickWall
Sourceimpl Default for SulfurBrickWall
impl Default for SulfurBrickWall
Sourceimpl From<SulfurBrickWall> for BlockState
impl From<SulfurBrickWall> for BlockState
Sourcefn from(b: SulfurBrickWall) -> Self
fn from(b: SulfurBrickWall) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SulfurBrickWall
impl PartialEq for SulfurBrickWall
Sourcefn eq(&self, other: &SulfurBrickWall) -> bool
fn eq(&self, other: &SulfurBrickWall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SulfurBrickWall