pub struct SulfurSlab {
pub kind: SlabKind,
pub waterlogged: bool,
}Fields
kind: SlabKindwaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for SulfurSlab
impl BlockTrait for SulfurSlab
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for SulfurSlab
impl Clone for SulfurSlab
Sourcefn clone(&self) -> SulfurSlab
fn clone(&self) -> SulfurSlab
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SulfurSlab
Sourceimpl Debug for SulfurSlab
impl Debug for SulfurSlab
Sourceimpl Default for SulfurSlab
impl Default for SulfurSlab
Sourceimpl From<SulfurSlab> for BlockState
impl From<SulfurSlab> for BlockState
Sourcefn from(b: SulfurSlab) -> Self
fn from(b: SulfurSlab) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SulfurSlab
impl PartialEq for SulfurSlab
Sourcefn eq(&self, other: &SulfurSlab) -> bool
fn eq(&self, other: &SulfurSlab) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SulfurSlab