pub struct SulfurSpike {
pub thickness: Thickness,
pub vertical_direction: VerticalDirection,
pub waterlogged: bool,
}Fields
thickness: Thicknessvertical_direction: VerticalDirectionwaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for SulfurSpike
impl BlockTrait for SulfurSpike
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for SulfurSpike
impl Clone for SulfurSpike
Sourcefn clone(&self) -> SulfurSpike
fn clone(&self) -> SulfurSpike
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SulfurSpike
Sourceimpl Debug for SulfurSpike
impl Debug for SulfurSpike
Sourceimpl Default for SulfurSpike
impl Default for SulfurSpike
Sourceimpl From<SulfurSpike> for BlockState
impl From<SulfurSpike> for BlockState
Sourcefn from(b: SulfurSpike) -> Self
fn from(b: SulfurSpike) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SulfurSpike
impl PartialEq for SulfurSpike
Sourcefn eq(&self, other: &SulfurSpike) -> bool
fn eq(&self, other: &SulfurSpike) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SulfurSpike