pub struct SulfurStairs {
pub facing: FacingCardinal,
pub half: TopBottom,
pub shape: StairShape,
pub waterlogged: bool,
}Fields
facing: FacingCardinalhalf: TopBottomshape: StairShapewaterlogged: boolTrait Implementations
Sourceimpl BlockTrait for SulfurStairs
impl BlockTrait for SulfurStairs
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for SulfurStairs
impl Clone for SulfurStairs
Sourcefn clone(&self) -> SulfurStairs
fn clone(&self) -> SulfurStairs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SulfurStairs
Sourceimpl Debug for SulfurStairs
impl Debug for SulfurStairs
Sourceimpl Default for SulfurStairs
impl Default for SulfurStairs
Sourceimpl From<SulfurStairs> for BlockState
impl From<SulfurStairs> for BlockState
Sourcefn from(b: SulfurStairs) -> Self
fn from(b: SulfurStairs) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SulfurStairs
impl PartialEq for SulfurStairs
Sourcefn eq(&self, other: &SulfurStairs) -> bool
fn eq(&self, other: &SulfurStairs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SulfurStairs