pub struct SulfurWall {
pub east: WallEast,
pub north: WallNorth,
pub south: WallSouth,
pub up: bool,
pub waterlogged: bool,
pub west: WallWest,
}Fields
east: WallEastnorth: WallNorthsouth: WallSouthup: boolwaterlogged: boolwest: WallWestTrait Implementations
Sourceimpl BlockTrait for SulfurWall
impl BlockTrait for SulfurWall
fn behavior(&self) -> BlockBehavior
Sourcefn as_block_state(&self) -> BlockState
fn as_block_state(&self) -> BlockState
Convert the block struct to a
BlockState. Read moreSourcefn property_map(&self) -> HashMap<&'static str, &'static str>
fn property_map(&self) -> HashMap<&'static str, &'static str>
Returns a map of property names on this block to their values as
strings. Read more
Sourcefn get_property(&self, name: &str) -> Option<&'static str>
fn get_property(&self, name: &str) -> Option<&'static str>
Get a property’s value as a string by its name, or
None if the block
has no property with that name. Read moreSourcefn set_property(
&mut self,
name: &str,
new_value: &str,
) -> Result<(), InvalidPropertyError>
fn set_property( &mut self, name: &str, new_value: &str, ) -> Result<(), InvalidPropertyError>
Update a property on this block, with the name and value being strings. Read more
Sourceimpl Clone for SulfurWall
impl Clone for SulfurWall
Sourcefn clone(&self) -> SulfurWall
fn clone(&self) -> SulfurWall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SulfurWall
Sourceimpl Debug for SulfurWall
impl Debug for SulfurWall
Sourceimpl Default for SulfurWall
impl Default for SulfurWall
Sourceimpl From<SulfurWall> for BlockState
impl From<SulfurWall> for BlockState
Sourcefn from(b: SulfurWall) -> Self
fn from(b: SulfurWall) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SulfurWall
impl PartialEq for SulfurWall
Sourcefn eq(&self, other: &SulfurWall) -> bool
fn eq(&self, other: &SulfurWall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SulfurWall